# Wagtail Vector Index

Wagtail Vector Index provides a way to turn Django models, Wagtail pages, and anything else in to embeddings which are stored in a one of multiple vector database backends.

This provides the backbone for features including:

-   Retrieval-augmented text generation (RAG)
-   Natural language search
-   Similarity search
-   Content recommendations
